@@ -4,6 +4,10 @@ use crate::{
 };
 use async_std::{fs, io};
 use cap_primitives::{ambient_authority, AmbientAuthority};
+#[cfg(not(windows))]
+use io_lifetimes::{AsFd, BorrowedFd, FromFd, IntoFd, OwnedFd};
+#[cfg(windows)]
+use io_lifetimes::{AsHandle, BorrowedHandle, FromHandle, IntoHandle, OwnedHandle};
 use std::fmt;
 use unsafe_io::OwnsRaw;
 #[cfg(unix)]
@@ -519,6 +523,14 @@ impl FromRawFd for Dir {
     }
 }
 
+#[cfg(not(windows))]
+impl FromFd for Dir {
+    #[inline]
+    fn from_fd(fd: OwnedFd) -> Self {
+        Self::from_std_file(fs::File::from_fd(fd), ambient_authority())
+    }
+}
+
 #[cfg(windows)]
 impl FromRawHandle for Dir {
     /// To prevent race conditions on Windows, the handle must be opened without
@@ -529,6 +541,14 @@ impl FromRawHandle for Dir {
     }
 }
 
+#[cfg(windows)]
+impl FromHandle for Dir {
+    #[inline]
+    fn from_handle(handle: OwnedHandle) -> Self {
+        Self::from_std_file(fs::File::from_handle(handle), ambient_authority())
+    }
+}
+
 #[cfg(not(windows))]
 impl AsRawFd for Dir {
     #[inline]
@@ -537,6 +557,14 @@ impl AsRawFd for Dir {
     }
 }
 
+#[cfg(not(windows))]
+impl AsFd for Dir {
+    #[inline]
+    fn as_fd(&self) -> BorrowedFd<'_> {
+        self.cap_std.as_fd()
+    }
+}
+
 #[cfg(windows)]
 impl AsRawHandle for Dir {
     #[inline]
@@ -545,6 +573,14 @@ impl AsRawHandle for Dir {
     }
 }
 
+#[cfg(windows)]
+impl AsHandle for Dir {
+    #[inline]
+    fn as_handle(&self) -> BorrowedHandle<'_> {
+        self.cap_std.as_handle()
+    }
+}
+
 #[cfg(windows)]
 impl AsRawHandleOrSocket for Dir {
     #[inline]
@@ -561,6 +597,14 @@ impl IntoRawFd for Dir {
     }
 }
 
+#[cfg(not(windows))]
+impl IntoFd for Dir {
+    #[inline]
+    fn into_fd(self) -> OwnedFd {
+        self.cap_std.into_fd()
+    }
+}
+
 #[cfg(windows)]
 impl IntoRawHandle for Dir {
     #[inline]
@@ -569,6 +613,14 @@ impl IntoRawHandle for Dir {
     }
 }
 
+#[cfg(windows)]
+impl IntoHandle for Dir {
+    #[inline]
+    fn into_handle(self) -> OwnedHandle {
+        self.cap_std.into_handle()
+    }
+}
+
 #[cfg(windows)]
 impl IntoRawHandleOrSocket for Dir {
     #[inline]
