@@ -4,7 +4,8 @@ use async_std::{
     stream::Stream,
     task::{Context, Poll},
 };
-use std::pin::Pin;
+use cap_primitives::{ambient_authority, AmbientAuthority};
+use std::{fmt, pin::Pin};
 
 /// An iterator that infinitely `accept`s connections on a [`TcpListener`].
 ///
@@ -18,12 +19,12 @@ pub struct Incoming<'a> {
 impl<'a> Incoming<'a> {
     /// Constructs a new instance of `Self` from the given `async_std::net::Incoming`.
     ///
-    /// # Safety
+    /// # Ambient Authority
     ///
     /// `async_std::net::Incoming` is not sandboxed and may access any address that the host
     /// process has access to.
     #[inline]
-    pub unsafe fn from_std(std: net::Incoming<'a>) -> Self {
+    pub fn from_std(std: net::Incoming<'a>, _: AmbientAuthority) -> Self {
         Self { std }
     }
 }
@@ -36,7 +37,7 @@ impl<'a> Stream for Incoming<'a> {
         Stream::poll_next(Pin::new(&mut self.std), cx).map(|poll| {
             poll.map(|result| {
                 let tcp_stream = result?;
-                Ok(unsafe { TcpStream::from_std(tcp_stream) })
+                Ok(TcpStream::from_std(tcp_stream, ambient_authority()))
             })
         })
     }
@@ -47,4 +48,8 @@ impl<'a> Stream for Incoming<'a> {
     }
 }
 
-// TODO: impl Debug for Incoming
+impl<'a> fmt::Debug for Incoming<'a> {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        self.std.fmt(f)
+    }
+}
