@@ -1,23 +1,21 @@
-//! A capability-oriented network API modeled after `async_std::net`.
-//!
-//! XXX: The interfaces in this module are not yet implemented.
+//! A capability-based network API modeled after `async_std::net`.
 //!
 //! This corresponds to [`async_std::net`].
 //!
 //! Instead of [`async_std::net`]'s constructor methods which take an address to
-//! connect to, this crates has methods on [`Catalog`] which operate on addresses
-//! which must be present in the catalog.
+//! connect to, this crates has methods on [`Pool`] which operate on addresses
+//! which must be present in the pool.
 //!
-//! [`Catalog`]: struct.Catalog.html
+//! [`Pool`]: struct.Pool.html
 
-mod catalog;
 mod incoming;
+mod pool;
 mod tcp_listener;
 mod tcp_stream;
 mod udp_socket;
 
-pub use catalog::*;
 pub use incoming::*;
+pub use pool::*;
 pub use tcp_listener::*;
 pub use tcp_stream::*;
 pub use udp_socket::*;
